@@ -786,6 +786,7 @@ g_tls_connection_base_real_pop_io (GTlsConnectionBase  *tls,
           g_set_error_literal (error, G_TLS_ERROR, G_TLS_ERROR_CERTIFICATE_REQUIRED,
                                _("Server required TLS certificate"));
         }
+      g_clear_error (&my_error);
     }
   else if (my_error)
     {
@@ -1239,6 +1240,7 @@ update_peer_certificate_and_compute_errors (GTlsConnectionBase *tls)
     peer_certificate_errors = verify_peer_certificate (tls, peer_certificate);
 
   g_set_object (&priv->peer_certificate, peer_certificate);
+  g_clear_object (&peer_certificate);
 
   priv->peer_certificate_errors = peer_certificate_errors;
 
